data "aws_instance" "monitored" {
  for_each    = toset(var.ec2_ids)
  instance_id = each.key
}

resource "aws_cloudwatch_metric_alarm" "cpu_critical" {
  for_each            = data.aws_instance.monitored
  alarm_name          = "CPU Usage:${each.value.tags.Name}:critical"
  comparison_operator = "GreaterThanOrEqualToThreshold"
  evaluation_periods  = "2"
  metric_name         = "CPUUtilization"
  namespace           = "AWS/EC2"
  period              = "60"
  statistic           = "Average"
  threshold           = "75"
  alarm_description   = "CPU alarm on ${each.value.tags.Name} IPs: ${each.value.public_ip} (${each.value.private_ip})"
  alarm_actions       = [aws_sns_topic.qw_alarms.arn]
  ok_actions          = [aws_sns_topic.qw_alarms.arn]

  dimensions = {
    InstanceId = each.value.id
  }
}


resource "aws_cloudwatch_metric_alarm" "mem_usage_critical" {
  for_each            = data.aws_instance.monitored
  alarm_name          = "MemUsage:${each.value.tags.Name}:critical"
  comparison_operator = "GreaterThanOrEqualToThreshold"
  evaluation_periods  = "1"
  metric_name         = "mem_used_percent"
  namespace           = "CWAgent"
  period              = "60"
  statistic           = "Average"
  threshold           = "80"
  alarm_description   = "Memory alarm on ${each.value.tags.Name} IPs: ${each.value.public_ip} (${each.value.private_ip})"
  alarm_actions       = [aws_sns_topic.qw_alarms.arn]
  ok_actions          = [aws_sns_topic.qw_alarms.arn]

  dimensions = {
    InstanceId = each.value.id
  }
}
