data "archive_file" "notify_js" {
  type        = "zip"
  source_file = "${path.module}/lambda/notification.js"
  output_path = "${path.module}/lambda/notification.zip"
}

resource "aws_lambda_function" "notify" {
  depends_on = [data.archive_file.notify_js]

  function_name = "${var.env}-notification"
  description   = "Send notifications to Mattermost"

  runtime = "nodejs12.x"
  handler = "notification.handler"

  role = aws_iam_role.notify.arn

  filename         = data.archive_file.notify_js.output_path
  source_code_hash = filebase64sha256(data.archive_file.notify_js.output_path)

  environment {
    variables = {
      NOTIFICATION_CHANNEL  = var.alert_notify_channel
      NOTIFICATION_USERNAME = var.alert_notify_user
      NOTIFICATION_WEBHOOK  = var.alert_notify_url
    }
  }
}

data "aws_iam_policy_document" "assume_role" {
  statement {
    effect = "Allow"
    actions = [
      "sts:AssumeRole",
    ]
    principals {
      type        = "Service"
      identifiers = ["lambda.amazonaws.com"]
    }
  }
}

resource "aws_iam_role" "notify" {
  name               = "${var.env}-alert-notify"
  assume_role_policy = data.aws_iam_policy_document.assume_role.json
}

data "aws_iam_policy_document" "notify" {
  statement {
    sid    = "CloudwatchLogs"
    effect = "Allow"
    actions = [
      "logs:CreateLogGroup",
      "logs:CreateLogStream",
      "logs:GetLogEvents",
      "logs:PutLogEvents"
    ]
    resources = ["arn:aws:logs:*:*:*"]
  }
}

resource "aws_iam_role_policy" "notify" {
  name   = "${var.env}-alert-notify"
  role   = aws_iam_role.notify.id
  policy = data.aws_iam_policy_document.notify.json
}

