resource "aws_sns_topic" "qw_alarms" {
  name         = "${var.env}-cloudwatch-alarms"
  display_name = "Cloudwatch Alarms (${var.env})"
}

resource "aws_lambda_permission" "perm_alarms" {
  statement_id  = "${var.env}-AllowExecutionFromCloudWatchSNSAlarms"
  action        = "lambda:InvokeFunction"
  function_name = aws_lambda_function.notify.arn
  principal     = "sns.amazonaws.com"
  source_arn    = aws_sns_topic.qw_alarms.arn
}

resource "aws_sns_topic_subscription" "sub_alarms" {
  depends_on = [aws_lambda_permission.perm_alarms]
  topic_arn  = aws_sns_topic.qw_alarms.arn
  protocol   = "lambda"
  endpoint   = aws_lambda_function.notify.arn
}

resource "aws_sns_topic" "qw_warnings" {
  name         = "${var.env}-cloudwatch-warnings"
  display_name = "Cloudwatch Warnings (${var.env})"
}

resource "aws_lambda_permission" "perm_warnings" {
  statement_id  = "${var.env}-AllowExecutionFromCloudWatchSNSWarnings"
  action        = "lambda:InvokeFunction"
  function_name = aws_lambda_function.notify.arn
  principal     = "sns.amazonaws.com"
  source_arn    = aws_sns_topic.qw_warnings.arn
}

resource "aws_sns_topic_subscription" "sub_warnings" {
  depends_on = [aws_lambda_permission.perm_warnings]
  topic_arn  = aws_sns_topic.qw_alarms.arn
  protocol   = "lambda"
  endpoint   = aws_lambda_function.notify.arn
}

output "alarms_topic" {
  value = aws_sns_topic.qw_alarms
}
output "warnings_topic" {
  value = aws_sns_topic.qw_warnings
}
