var https = require('https');
var util = require('util');

const colors = {
    ERROR: '#e80e07',
    WARNING: '#fceb03',
    INFO: '#7CD197'
}
/** 
 * Performs https post requies to Slack/Mattermost in with async/await
 */
function doRequest(url, options, data) {
    return new Promise((resolve, reject) => {
        const req = https.request(url, options, (res) => {
            res.setEncoding('utf8');
            let responseBody = '';

            res.on('data', (chunk) => {
                responseBody += chunk;
            });

            res.on('end', () => {
                console.log("Messeage sent to:" + data.channel)
                resolve();
            });
        });

        req.on('error', (err) => {
            reject(err);
        });

        req.write(util.format("%j", data));
        req.end();
    });
}

function preparePayload(event) {
    var notif = event.Records[0];

    if (notif.EventSubscriptionArn.includes('cloudwatch-alarms')) {
        return prepareCWAlarmPayload(notif);
    }

    if (notif.EventSubscriptionArn.includes('cloudwatch-warnings')) {
        return prepareCWAlarmPayload(notif);
    }

}

function prepareCWAlarmPayload(record) {
    var message = JSON.parse(record.Sns.Message);
    var color = colors.INFO;

    if (message.NewStateValue === "ALARM") {
        color = colors.ERROR;
    }

    // Check if Alarm trigger is available

    var metricName = "unknown";
    var threshold = "unknown";
    var dimensions = " \r\n";
    var trigger = message.Trigger

    if (trigger) {
        metricName = `${trigger.Namespace}/${trigger.MetricName}`
        threshold = `${trigger.ComparisonOperator} ${trigger.Threshold}`

        trigger.Dimensions.forEach(element => {
            dimensions = `${dimensions}${element.name}: \`${element.value}\`\r\n`
        });
    }

    var postData = {
        channel: null,

        attachments: [{
            title: "CloudWatch Alarm",
            color,
            fields: [
                {
                    title: 'State',
                    value: message.NewStateValue,
                    short: true,
                }, {
                    title: 'Alarm',
                    value: message.AlarmName,
                    short: true,
                },
                {
                    title: 'Metric',
                    value: metricName,
                    short: true,
                },
                {
                    title: 'Threshold',
                    value: threshold,
                    short: true,
                },
                {
                    title: 'Reason',
                    value: `${message.NewStateReason} \r\n${dimensions} `,
                    short: false,
                }]
        }]
    };

    return postData;
}

exports.handler = async function (event, context) {
    try {

        var channel = process.env.NOTIFICATION_CHANNEL
        var username = process.env.NOTIFICATION_USERNAME
        var webhookUrl = process.env.NOTIFICATION_WEBHOOK

        var urlsList = webhookUrl.split(',')
        var channelsList = channel.split(',')
        var outboundConfig = []

        if (urlsList.length !== channelsList.length) {
            throw new Error('Configuration error, number of channels is not equal to number of URLs');
        }

        for (let index = 0; index < urlsList.length; index++) {
            outboundConfig.push({
                url: urlsList[index],
                channel: channelsList[index]
            })
        }

        var options = {
            method: 'POST'
        };

        var postData = preparePayload(event);


        for (let index = 0; index < outboundConfig.length; index++) {
            var _url = outboundConfig[index].url;
            var _channel = outboundConfig[index].channel;
            postData.channel = _channel;
            postData.username = username;
            await doRequest(_url, options, postData)
        }

        context.done(null);



    } catch (e) {
        context.fail(e)
    }
};